NullableKind<T> class final

Kind for nullable types.

Example

import 'package:kind/kind.dart';

final nullableString = StringKind().toNullable();
``
Inheritance

Constructors

NullableKind(Kind<T> elementKind)
const

Properties

dartType → Type
Type T.
no setterinherited
defaultValueMirror → InstanceMirror
InstanceMirror for the default value.
no setterinherited
elementKind → Kind<T>
Non-nullable kind.
final
equality → Equality
Equality for the kind;
no setterinherited
examples → Iterable<T?>
Examples of instances that are valid (isValidDynamic).
no setterinherited
examplesThatAreInvalid → Iterable<T?>
Examples of instances that are NOT valid (isValidDynamic).
no setterinherited
examplesWithoutValidation → Iterable<T?>
Interesting examples of instances (may be valid or invalid).
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
isNullable → bool
Whether this kind is nullable.
no setteroverride
isPrimitive → bool
Whether instances of the kind can't have references to other instances.
no setterinherited
jsonName → String?
JSON identifier of the class.
finalinherited
name → String
Dart identifier of the class.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traits → List<Trait>
Traits of the kind.
no setteroverride

Methods

asType(Object? value) → T?
Casts value to T.
inherited
checkDeclaration() → void
Checks that the declaration makes sense.
inherited
checkInstance(Object? value) → void
inherited
checkValid(T? instance) → void
override
checkValidDynamic(Object? instance) → void
Throws ArgumentError error if instance is not valid (isValidDynamic).
inherited
clone(T? instance) → T?
Clones the instance.
override
compare(T? left, T? right) → int
Compares two values.
override
debugString(T? instance) → String
Constructs a string for debugging instance.
override
decodeJsonTree(Object? json) → T?
Converts json (any JSON tree) to an instance of T.
override
decodeString(String string) → T?
Decodes string to an instance of T.
inherited
encodeJsonTree(T? instance) → Object?
Converts instance to a JSON tree.
override
encodeString(T? instance) → String
Converts instance to a string.
inherited
isDefaultValue(Object? instance) → bool
Determines whether the argument is a default value of this kind.
override
isInstance(Object? instance) → bool
Determines whether the argument is an instance of T.
inherited
isInstanceOfList(Object? instance) → bool
Determines whether the argument is an instance of List<T>.
inherited
isInstanceOfSet(Object? instance) → bool
Determines whether the argument is an instance of Set<T>.
inherited
isNullableSubKind(Kind other, {bool andNotEqual = true}) → bool
Tells whether the argument is instance of Kind<T> and dartType values are different.
inherited
isSubKind(Kind other, {bool andNotEqual = true}) → bool
Tells whether the argument is instance of Kind<T> and dartType values are different.
inherited
isValid(T? instance) → bool
Tells whether the instance is valid.
override
isValidDynamic(Object? instance) → bool
Tells whether the instance is valid.
inherited
memorySize(T? instance) → int
Estimates memory usage of instance.
override
memorySizeWith(MemoryCounter counter, T? instance) → void
Estimates memory usage with an instance of MemoryCounter.
override
newInstance() → T?
Constructs a new instance of the default value.
override
newList(int length, {bool growable = true}) → List<T?>
Constructs a new list.
inherited
newListFrom(Iterable<T?> iterable, {bool growable = true}) → List<T?>
Constructs a new list from iterable.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
permute(T? instance) → T?
Generates another instance with some deterministic function.
override
register() → void
Registers this kind so that it will be visible in Kind.all.
inherited
toList() → Kind<List<T?>>
Constructs Kind for List<T>.
inherited
toNonNullable() → Kind<T>
Returns a non-nullable kind.
override
toNullable() → NullableKind<T>
Constructs Kind for T?.
override
toPolymorphic() → PolymorphicKind<T?>
Constructs a PolymorphicKind for this kind.
inherited
toSet() → Kind<Set<T?>>
Constructs Kind for Set<T>.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override