ValidationError class

Validation error added to ValidateContext.

Inheritance

Constructors

ValidationError({required Object? value, String? message, List? path})

Properties

hashCode int
The hash code for this object.
no setteroverride
message String?
final
path List?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited
value Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override